#
# spec file for package python3-ec2imgutils
#
# Copyright (c) 2018 SUSE Linux GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define upstream_name ec2imgutils

Name:           python3-ec2imgutils
Version:        10.0.2
Release:        1.2
Summary:        Image management utilities for AWS EC2
License:        GPL-3.0+
Group:          System/Management
Url:            https://github.com/SUSE-Enceladus/ec2imgutils
Source0:        %{upstream_name}-%{version}.tar.bz2
Requires:       python3
Requires:       python3-boto3 >= 1.26.89
Requires:       python3-dateutil
Requires:       python3-paramiko
BuildRequires:  python3-boto3 >= 1.26.89
BuildRequires:  python3-dateutil
BuildRequires:  python3-setuptools
BuildRequires:  python-rpm-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

# Package renamed in SLE 12 do not remove Provides, Obsolete
# directives until after SLE 12 EOL
Provides:       python-ec2utilsbase = %{version}
Obsoletes:      python-ec2utilsbase < %{version}
Provides:       python-ec2deprecateimg = %{version}
Obsoletes:      python-ec2deprecateimg < %{version}
Provides:       python-ec2publishimg = %{version}
Obsoletes:      python-ec2publishimg < %{version}
Provides:       python-ec2uploadimg = %{version}
Obsoletes:      python-ec2uploadimg < %{version}

# Package rename in SLE 15 GA do not remove Provides, Obsolete
# directives until after SLE 15 SP3 EOL
Provides:       python3-ec2utilsbase = %{version}
Obsoletes:      python3-ec2utilsbase < %{version}
Provides:       python3-ec2deprecateimg = %{version}
Obsoletes:      python3-ec2deprecateimg < %{version}
Provides:       python3-ec2publishimg = %{version}
Obsoletes:      python3-ec2publishimg < %{version}
Provides:       python3-ec2uploadimg = %{version}
Obsoletes:      python3-ec2uploadimg < %{version}

%description
A collection of image manipulation utilities for AWS EC2. These include:
- ec2deprecateimg: Deprecates images by applying tags per convention
- ec2publishimg: Set image visibility
- ec2uploadimg: Upload an image to AWS EC2

%prep
%setup -q -n %{upstream_name}-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
install -d -m 755 %{buildroot}/%{_mandir}/man1
install -m 644 man/man1/* %{buildroot}/%{_mandir}/man1
gzip %{buildroot}/%{_mandir}/man1/*

%files
%defattr(-,root,root,-)
%doc README.md
%license LICENSE
%{_mandir}/man*/*
%dir %{python3_sitelib}/ec2imgutils
%{python3_sitelib}/*
%{_bindir}/*

%changelog
* Wed Jun  7 2023 Robert Schweikert <rjschwei@suse.com>
- Fix version confusion between boto3 nd botocore for dependency
* Wed Apr 26 2023 Robert Schweikert <rjschwei@suse.com>
- Update to version 10.0.2 (bsc#1209255, jsc#PED-3781)
  + Add 'uefi-preferred' boot mode setting
* Tue May 24 2022 Robert Schweikert <rjschwei@suse.com>
- Update to version 10.0.1
  + Follow up fix to (bsc#1199722) allow the user a choice of 2.0 and v2.0 as
    tpm versions on the command line
* Thu May 19 2022 Robert Schweikert <rjschwei@suse.com>
- Update to version 10.0.0 (bsc#1199722)
  + Add --tpm-support as command line option and tpm_support to the API
    to register images that support NitroTPM
  + API change for ec2deprecateimg. It is now possible to deprecate
    an image without providing a successor image.
* Fri Dec 17 2021 Sean Marlow <sean.marlow@suse.com>
- Add rpm-macros to build requirements in spec.
* Wed Nov  3 2021 Robert Schweikert <rjschwei@suse.com>
- Update to version 9.0.4 (bsc#1192298)
  + Set a time out for the ssh connection to avoid hang in a multi threaded
    environment
* Tue Sep 14 2021 Robert Schweikert <rjschwei@suse.com>
- Update to version 9.0.3 (bsc#1190538)
  + Support setting the boot mode for EC2 images, either to legacy-bios
    or uefi. Argument is optional, without it instance will use the default
    boot mode for the given instance type.
* Fri Aug 20 2021 Robert Schweikert <rjschwei@suse.com>
- Update to version 9.0.2 (bsc#1189649)
  + In addition to tagging images in AWS also set them to deprecated
    in EC2. This allows the framework to hide the images from new users
    when images are no longer supposed to be used.
* Sat Dec 12 2020 Robert Schweikert <rjschwei@suse.com>
- Update to version 9.0.1 (bsc#1179890)
  + Support gp3 as option to create EBS root volume. This allows image
    creation with the new storage class and save 20%% of cost.
* Mon Aug 24 2020 Robert Schweikert <rjschwei@suse.com>
- Update to version 9.0.0
  + Handle traceback generated by ec2uploadimg
  + Fix ec2removeimg implementation w.r.t. missing implementation of
    delete confirmation when multiple images are to be deleted
* Mon Jun 15 2020 Sean Marlow <sean.marlow@suse.com>
- Update to version 8.1.2 (bsc#1172948)
  + Fix regression in deprecation and list image related to logger
    changes.
* Mon Jun  8 2020 Robert Schweikert <rjschwei@suse.com>
- Update to version 8.1.1
  + Handle log adapter when getting log_level and set log_level as
    instance attr
* Fri Jun  5 2020 Robert Schweikert <rjschwei@suse.com>
- Update to version 8.1.0 (bsc#1172579)
  + Do not call the AWS API if the image copy setting has no value to avoid
    an API error.
  + Add new utility ec2listimg to list images owned by the specified account
  + Switch all code to support output to a logger
* Wed May 20 2020 Robert Schweikert <rjschwei@suse.com>
- Update to version 8.0.0 (bsc#1171933)
  + Incompatible command line argument change for ec2publishimg. The
  - -allow-copy option is no longer a bolean. It now supports the
    image and none keywords as well as a comma separated list of AWS account
    numbers.
  + Support having the snapshot copy permissions set differently than the
    image copy permissions. This supports published image aggregation into
    AWS MP.
  + ec2uploadimg tags the helper instance
* Thu Mar 19 2020 Robert Schweikert <rjschwei@suse.com>
- Update to version 7.0.9 (bsc#1167148)
  + Support uploading with helper instances that handle disk attachments
    via NVMe protocol
  + Improve output of help for clarity
  + Improve progress message for ssh connection to make it easier to
    discover issues
  + Fix implementation for using root-swap method with a running instance
* Wed Feb  5 2020 Robert Schweikert <rjschwei@suse.com>
- Update to version 7.0.8 (bsc#1162712)
  + For ARM image upload automatically enable ENA support. ARM based
    instances require the ENA driver in the kernel
* Thu Nov 14 2019 Sean Marlow <sean.marlow@suse.com>
- Update to version 7.0.7
  + Fix cleanup with --use-root-swap img upload.
- Update to version 7.0.6
  + Add requirements files to manifest.
  + Avoid race condition with security group creation.
  + Remove code duplication when avoiding group name
    collision.
* Mon Aug  5 2019 Robert Schweikert <rjschwei@suse.com>
- Update to version 7.0.5 (bsc#1144357, 1144358)
  + Avoid name collision when creating a security group with a
    generated nmae.
* Wed Dec 19 2018 Robert Schweikert <rjschwei@suse.com>
- Update to version 7.0.4
  + Fix traceback in ec2rmimg due to variable name issue
  + Use proper subnet when no default exists in user account
  + Properly enforce use of machine argument and support ARM (bsc#1118027)
* Fri Nov 16 2018 Robert Schweikert <rjschwei@suse.com>
- Fix build issue, tarball had missing files
* Thu Nov 15 2018 Robert Schweikert <rjschwei@suse.com>
- Update to version 7.0.3
  + General improvements, latent bug fixes
* Fri Nov  9 2018 Robert Schweikert <rjschwei@suse.com>
- Update to version 7.0.2
  + Fix syntax error in ec2deprecateimg, ec2publishimg, ec2removeimg
* Fri Nov  9 2018 Robert Schweikert <rjschwei@suse.com>
- Update to version 7.0.1
  + Fix syntax error in ec2uploadimg
* Tue Nov  6 2018 Robert Schweikert <rjschwei@suse.com>
- Update to version 7.0.0
  + Complete ec2removeimg implementation
  + Ready for release and replacement of individual packages
* Thu Nov  1 2018 Robert Schweikert <rjschwei@suse.com>
- Update to version 6.9.99
  + Initial implementation of ec2removeimg
* Thu Sep 27 2018 Robert Schweikert <rjschwei@suse.com>
- Initial build
  + Version 6.9.98
  + First consolidation build of ec2deprecateimg, ec2publishimg, ec2uploadimg
